SystemOrganization addCategory: #'PW-Tests-Parsing'!

TestCase subclass: #PWDocumentActorTest
	instanceVariableNames: 'parser flow chars grammar document actor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-Tests-Parsing'!

PWDocumentActorTest subclass: #PWCollectDocumentObjectsTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-Tests-Parsing'!

!PWCollectDocumentObjectsTest methodsFor: 'as yet unclassified' stamp: 'chc 9/15/2016 08:12'!
setUp
	super setUp. 

! !

!PWCollectDocumentObjectsTest methodsFor: 'as yet unclassified' stamp: 'chc 9/21/2016 08:26'!
testFiveSpacesAndNewlineCollected
	| string1 string2 input documents |
	string1 := String fromString: '     '.
	string2 := String with: Character cr with: Character lf.
	input := string1 , string2.
	input := input withUnixLineEndings.
	documents := parser parse: 'Page' stream: input reading actor: PWDocumentActor new.	
	self assert: (documents size = 1).
	self assert: (documents first isKindOf: TWParagraph)! !

!PWCollectDocumentObjectsTest methodsFor: 'as yet unclassified' stamp: 'chc 9/21/2016 08:17'!
testFiveSpacesStringCollected
	| input documents |
	input := '     '.
	documents := parser parse: 'Page' stream: input reading actor: PWDocumentActor new.	
	self assert: (documents size = 1).
	self assert: (documents first isKindOf: TWParagraph)! !

!PWCollectDocumentObjectsTest methodsFor: 'as yet unclassified' stamp: 'chc 9/15/2016 08:42'!
testHeadingCollected
	| input documents |
	input := '= Hello Heading ='.
	documents := parser parse: 'Page' stream: input reading actor: PWDocumentActor new.
	self assert: (documents size = 1).
	self assert: (documents first isKindOf: TWHeading)! !

!PWCollectDocumentObjectsTest methodsFor: 'as yet unclassified' stamp: 'chc 9/21/2016 08:14'!
testNewline
	| input documents |
	"this is how the input string comes from the browser on Linux and Mac, with crlf"
	input := String with: Character cr with: Character lf. 
	"In VisualWorks the \n is interpreted as a cr" 
	"the PEGParser grammarWiki sees \n as lf so I convert input to Linux line endings"
	input := input withUnixLineEndings.
	documents := parser parse: 'Page' stream: input reading actor: PWDocumentActor new.	
	self assert: (documents size = 1).
	self assert: (documents first isKindOf: TWParagraph)! !

!PWCollectDocumentObjectsTest methodsFor: 'as yet unclassified' stamp: 'chc 9/15/2016 08:13'!
testOneParagraphCollected
	| input documents |
	input := 'Edit your page'.
	documents := parser parse: 'Page' stream: input reading actor: PWDocumentActor new.
	self assert: (documents size = 1).
	self assert: (documents first isKindOf: TWParagraph)! !

!PWCollectDocumentObjectsTest methodsFor: 'as yet unclassified' stamp: 'chc 9/15/2016 08:50'!
testSingleSpaceStringCollected
	| input documents |
	input := ' '.
	documents := parser parse: 'Page' stream: input reading actor: PWDocumentActor new.	
	self assert: (documents size = 1).
	self assert: (documents first isKindOf: TWParagraph)! !

!PWCollectDocumentObjectsTest methodsFor: 'as yet unclassified' stamp: 'chc 9/21/2016 08:28'!
testTwoParagraphsCollected
	| input documents |
	input := 'Edit your page
	Edit your paper'.
	documents := parser parse: 'Page' stream: input reading actor: PWDocumentActor new.
	self assert: (documents size = 2).
	self assert: (documents second isKindOf: TWParagraph)! !

!PWDocumentActorTest methodsFor: 'as yet unclassified' stamp: 'chc 9/20/2016 10:11'!
setUp
	| grammar oc1 oc2|
	grammar := PEGParser grammarPEGWiki.
	oc1 := OrderedCollection new.
	oc1 add: $E; add: $d; add: $i; add: $t; add: Character space; add: $y; add: $o; add: $u; add: $r; add: Character space; add: $p; add: $a; add: $g; add: $e.
	oc2 := OrderedCollection new.
	oc2 add: oc1.
	chars := oc2.
	actor := PWDocumentActor new.
	document := ((TWFolder new initializeHome) at: 'Home') document.
	parser := PEGParser parserPEG parse: 'Grammar' stream: grammar actor: PEGParserParser new.
	
	! !

!PWDocumentActorTest methodsFor: 'as yet unclassified' stamp: 'chc 9/14/2016 10:53'!
testTWComponent
	|comp|
	comp := parser parse: 'Component' stream: '!!!!ALCounterExample!!!!' actor: actor.
	self assert: ( comp children first respondsTo: #renderOn: )! !

!PWDocumentActorTest methodsFor: 'as yet unclassified' stamp: 'chc 9/14/2016 11:42'!
testTWHeading
	| control heading|
	control := document children first.
	heading := parser parse: 'Heading1' stream: '  = Home =
	' actor: actor.
	self assert: (control children first text = heading children first text )! !

!PWDocumentActorTest methodsFor: 'as yet unclassified' stamp: 'chc 9/12/2016 10:47'!
testTWParagraph
	| control para |
	control := document children second.
	para := parser parse: 'Paragraph' stream: 'Edit your page' actor: actor.
	self assert: (control children first text = para children first text)! !

!PWDocumentActorTest methodsFor: 'as yet unclassified' stamp: 'chc 9/14/2016 11:40'!
testWholePage
	"copied from ParserWikiTest>>#testHeading in VisualWorks Xtreams-Parsing-Tests"
		| input output |
	input :=
'	= Hello _World_ =
Good _Bye_ *[World>http://www.google.com]*

[Short-Link]
* Bullet1 < Bullet2
* Bullet2
# Numbered
## Nested
---
	preformatted	text
---
{{{
	code
}}}
and again
	|| Heading1	|| Heading2
	|| Data 1		|| Data2
	|| Data 3		|| Data4
After table'.
	output := parser parse: 'Page' stream: input reading actor: PWDocumentActor new.
	self assert: output printString =
 '<div>
	<h1>
		Hello 
		<span style="font-style: italic">World</span>
	</h1>
	<p>
		Good 
		<span style="font-style: italic">Bye</span>
		 
		<span style="font-weight: bold">
			<a href="http://www.google.com">World</a>
		</span>
	</p>
	
	<p>
		<a href="Short-Link.html">Short-Link</a>
	</p>
	<ul>
		<li> Bullet1 &lt; Bullet2</li>
		<li> Bullet2</li>
	</ul>
	<ol>
		<li> Numbered</li>
		<li>
			<ol>
				<li> Nested</li>
			</ol>
		</li>
	</ol>
	<pre>	preformatted	text
</pre>
	<pre>	code
</pre>
	<p>and again</p>
	<table>
		<tableHead>
			<tr>
				<th> Heading1	</th>
				<th> Heading2</th>
			</tr>
		</tableHead>
		<tableBody>
			<tr>
				<td> Data 1		</td>
				<td> Data2</td>
			</tr>
			<tr>
				<td> Data 3		</td>
				<td> Data4</td>
			</tr>
		</tableBody>
	</table>
	<p>After table</p>
</div>'! !

TestCase subclass: #PWFormDataToParserTest
	instanceVariableNames: 'wikistring model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-Tests-Parsing'!

!PWFormDataToParserTest methodsFor: 'as yet unclassified' stamp: 'chc 9/12/2016 11:05'!
setUp
	wikistring := '= Home =
Edit your page'.
	model := PWPage new.! !

!PWFormDataToParserTest methodsFor: 'as yet unclassified' stamp: 'chc 9/12/2016 11:10'!
testWikiStringFromFormToParser
	| control document |
	control := ((TWFolder new initializeHome) at: 'Home') document.
	document := TWDocument withAll: (model parser parse: 'Page' stream: wikistring unescapePercents  actor: PWDocumentActor new).
	self assert: (control children first children first text = document children first children first text)! !

TestCase subclass: #PWPEGParserParserTests
	instanceVariableNames: 'parser'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-Tests-Parsing'!

!PWPEGParserParserTests commentStamp: '<historical>' prior: 0!
A terminal here is an OrderedCollection that does not contain another OrderedCollection. A terminal's contents is chars or strings. In the #grammarWiki that could be: 

Bold <- "*" Flow{"*"}

Angle brackets (i.e. {}) show that something is optional. To create a bold word you need an asterisk befor a or line. It will not contain any further OrderedCollections.  !

!PWPEGParserParserTests methodsFor: 'empty space identifiers' stamp: 'chc 9/27/2016 09:09'!
setUp
	parser := PEGParser parserBootstrap parse: 'Grammar' stream:  PEGParser grammarPEG reading actor: PEGParserParser new.! !

!PWPEGParserParserTests methodsFor: 'empty space identifiers' stamp: 'chc 9/27/2016 09:29'!
testLineCharacter
	| parserwithgrammar result |
	parserwithgrammar := parser parse: 'Grammar' stream: 'LineCharacter <- [^\n]' actor: PEGParserParser new.
	result := parserwithgrammar grammar at: 'LineCharacter'.
	self assert: (result isKindOf: BlockClosure)! !

!PWPEGParserParserTests methodsFor: 'empty space identifiers' stamp: 'chc 9/27/2016 10:20'!
testLineCharacterNewlineOrigin
	| parserwithgrammar result |
	"Why does the grammar think \n is a lf and not a cr?"
	parserwithgrammar := parser parse: 'Grammar' stream: 'LineCharacter <- [^w]' actor: PEGParserParser new.
	result := parserwithgrammar grammar at: 'LineCharacter'.
	self assert: (result isKindOf: BlockClosure)! !

TestCase subclass: #PWPEGParserTests
	instanceVariableNames: 'parser'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-Tests-Parsing'!

!PWPEGParserTests commentStamp: '<historical>' prior: 0!
A terminal here is an OrderedCollection that does not contain another OrderedCollection. A terminal's contents is chars or strings. In the #grammarWiki that could be: 

Bold <- "*" Flow{"*"}

Angle brackets (i.e. {}) show that something is optional. To create a bold word you need an asterisk befor a or line. It will not contain any further OrderedCollections.  !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 9/27/2016 10:21'!
setUp
	| grammar |
	grammar := PEGParser grammarPEGWiki.
	parser := PEGParser parserPEG parse: 'Grammar' stream: grammar actor: PEGParserParser new.
	! !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 9/26/2016 10:53'!
testEmpty
	| input result |
	input := '   
	' collect: [:ea| ea = Character cr]. 
	result := parser parse: 'Empty' stream: input reading actor: nil.
	self assert: ( result = Character lf )! !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 9/26/2016 10:36'!
testLineCharacter
	| input result |
	input := String with: Character lf. 
	result := parser parse: 'LineCharacter' stream: input reading actor: nil.
	self assert: ( result = Character lf )! !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 8/31/2016 09:36'!
testLinkShort
	| result |
	result := parser parse: 'LinkShort' stream: '[abc]' actor: nil.
	self assert: ( '<a href="http://www.abc.com">abc</a>' = result )! !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 9/7/2016 09:38'!
testParsedContentCreation
	| oc1 oc2 parsedresult |
	oc1 := OrderedCollection new.
	oc1 add: $E; add: $d; add: $i; add: $t; add: Character space; add: $y; add: $o; add: $u; add: $r; add: Character space; add: $p; add: $a; add: $g; add: $e.
	oc2 := OrderedCollection new.
	oc2 add: oc1.
	parsedresult := parser parse: 'Page' stream: 'Edit your page' reading actor: nil.
	self assert: ( oc2 = parsedresult )! !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 9/7/2016 09:43'!
testParsedContentSimulation
	| oc1 oc2 parsedresult |
	oc1 := OrderedCollection new.
	oc1 add: $E; add: $d; add: $i; add: $t; add: Character space; add: $y; add: $o; add: $u; add: $r; add: Character space; add: $p; add: $a; add: $g; add: $e.
	oc2 := OrderedCollection new.
	oc2 add: oc1.
	parsedresult := parser parse: 'Page' stream: 'Edit your page' reading actor: nil.
	self assert: ( oc2 = parsedresult )! !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 9/26/2016 11:01'!
testPreformatted
	| input result |
	input := '='.
	input at: 1 put: Character lf.
	result := parser parse: 'Empty' stream: input reading actor: nil.
	self assert: ( result = Character lf )! !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 9/26/2016 11:56'!
testWhitespace
	| input result control |
	input := String with: Character tab with: Character cr with: Character lf.
	result := parser parse: 'Whitespace' stream: input reading actor: nil.
	control := OrderedCollection withAll: (String with: Character tab with: Character tab with: Character tab). 
	self assert: ( result = control )! !

TestCase subclass: #PWStringActorTest
	instanceVariableNames: 'parser stream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-Tests-Parsing'!

!PWStringActorTest commentStamp: '<historical>' prior: 0!
A terminal here is an OrderedCollection that does not contain another OrderedCollection. A terminal's contents is chars or strings. In the #grammarWiki that could be: 

Bold <- "*" Flow{"*"}

Angle brackets (i.e. {}) show that something is optional. To create a bold word you need an asterisk befor a or line. It will not contain any further OrderedCollections.  !

!PWStringActorTest methodsFor: 'page structure' stamp: 'chc 9/12/2016 10:28'!
setUp
	| grammar |
	stream := 'Red Letter'.
	grammar := PEGParser grammarWiki.
	parser := PEGParser parserPEG parse: 'Grammar' stream: grammar actor: PEGParserParser new.
	! !

!PWStringActorTest methodsFor: 'single node ' stamp: 'chc 11/30/2016 11:08'!
testBold
	| result |
	result := parser parse: 'Bold' stream: '*' , stream , '*' actor: PWWikiActor new.
	self assert: ( '<b>Red Letter</b>' = result )! !

!PWStringActorTest methodsFor: 'double node' stamp: 'chc 11/30/2016 11:08'!
testBullet1
	| result |
	result := parser parse: 'Bullet1' stream: stream actor: PWWikiActor new.
	self assert: ( '<li>Red Letter</li>' = result )! !

!PWStringActorTest methodsFor: 'single node ' stamp: 'chc 11/30/2016 11:08'!
testCode
	| result |
	result := parser parse: 'Code' stream: '{{{
code
}}}' actor: PWWikiActor new.
	self assert: ( '<pre>
code
</pre>' = result )! !

!PWStringActorTest methodsFor: 'single node ' stamp: 'chc 11/30/2016 11:08'!
testHeading1
	| result |
	result := parser parse: 'Heading1' stream: '  = ' , stream actor: PWWikiActor new.
	self assert: ( '<h1>Red Letter</h1>' = result )! !

!PWStringActorTest methodsFor: 'single node ' stamp: 'chc 11/30/2016 11:08'!
testHeading2
	| result |
	result := parser parse: 'Heading2' stream: '  == ' , stream , ' == 
				' actor: PWWikiActor new.
	self assert: ( '<h2>RedLetter</h2>' = result )! !

!PWStringActorTest methodsFor: 'single node ' stamp: 'chc 11/30/2016 11:08'!
testHeading3
	| result |
	result := parser parse: 'Heading3' stream: '  === ' , stream , ' ===
				' actor: PWWikiActor new.
	self assert: ( '<h3>RedLetter</h3>' = result )! !

!PWStringActorTest methodsFor: 'single node ' stamp: 'chc 11/30/2016 11:08'!
testItalic
	| result |
	result := parser parse: 'Italic' stream: '_ ' , stream , ' _' actor: PWWikiActor new.
	self assert: ( '<i>Red Letter</i>' = result )! !

!PWStringActorTest methodsFor: 'single node ' stamp: 'chc 11/30/2016 11:08'!
testLink
	| result |
	result := parser parse: 'LinkShort' stream: '[' , stream , ']' actor: PWWikiActor new.
	self assert: ( '<a href="Red Letter.html">Red Letter</a>' = result )! !

!PWStringActorTest methodsFor: 'single node ' stamp: 'chc 11/30/2016 11:09'!
testLinkFull
	| result |
	result := parser parse: 'LinkFull' stream: '[World>http://www.google.com]' actor: PWWikiActor new.
	self assert: ( '<a href="http://www.google.com">World</a>' = result )! !

!PWStringActorTest methodsFor: 'page structure' stamp: 'chc 11/30/2016 11:09'!
testPage
	| result |
	result := parser parse: 'Page' stream: stream actor: PWWikiActor new.
	self assert: ( '<div><p>Red Letter</p></div>' = result )! !

!PWStringActorTest methodsFor: 'single node ' stamp: 'chc 11/30/2016 11:09'!
testPreformatted
	| result |
	result := parser parse: 'Preformatted' stream: '---' , Character cr , stream actor: PWWikiActor new.
	self assert: ( '<pre>Red Letter</pre>' = result )! !
